# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from codenerix_payments.models import PaymentRequest

import time
import datetime
import hashlib

from django.db import migrations, models

def remake_locators(apps, schema_editor):
    prs = PaymentRequest.objects.all()
    for pr in prs:
        pr.locator=hashlib.sha1(str(time.time())+str(datetime.datetime.now().microsecond)).hexdigest()
        pr.save()

class Migration(migrations.Migration):
    
    dependencies = [
        ('codenerix_payments', '0015_paymentrequest_locator'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentrequest',
            name='locator',
            field=models.CharField(default=b'94d5eeeaab540b416bd27fdbba990931501d3853', max_length=40, verbose_name='Locator'),
        ),
        migrations.RunPython(remake_locators)
    ]





# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-08 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0018_auto_20170303_0839'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='action',
            field=models.CharField(choices=[('confirm', 'Confirm'), ('cancel', 'Cancel')], max_length=7, verbose_name='Action'),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='protocol',
            field=models.CharField(choices=[('paypal', 'Paypal'), ('redsys', 'Redsys'), ('redsysxml', 'Redsys XML')], max_length=10, verbose_name='Protocol'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0009_paymentrequest_order'),
        ('codenerix_payments', '0003_auto_20160825_0838'),
    ]

    operations = [
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0016_auto_20161021_1154'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentrequest',
            name='locator',
            field=models.CharField(unique=True, max_length=40, verbose_name='Locator'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0008_auto_20160825_0809'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentrequest',
            name='order',
            field=models.PositiveIntegerField(default=0, verbose_name='Order Reference', validators=[django.core.validators.MaxValueValidator(2821109907455)]),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0013_auto_20160829_1443'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='ref',
            field=models.CharField(default=None, max_length=50, null=True, verbose_name='Reference'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creado')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(unique=True, max_length=15, verbose_name='Nombre')),
                ('symbol', models.CharField(unique=True, max_length=2, verbose_name='Simbolo')),
                ('iso4217', models.CharField(unique=True, max_length=3, verbose_name='ISO 4217 Code')),
                ('price', models.FloatField(verbose_name='Precio')),
            ],
            options={
                'permissions': [('list_currency', 'Can list currency'), ('detail_currency', 'Can view currency')],
            },
        ),
        migrations.CreateModel(
            name='PaymentAnswer',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creado')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('ref', models.CharField(default=None, max_length=50, null=True, verbose_name='Referencia')),
                ('error', models.BooleanField(default=False, verbose_name='Error')),
                ('error_txt', models.TextField(null=True, verbose_name='Error del text', blank=True)),
                ('request', models.TextField(null=True, verbose_name='Solicitud', blank=True)),
                ('answer', models.TextField(null=True, verbose_name='Respuesta', blank=True)),
                ('request_date', models.DateTimeField(verbose_name='Fecha de solicitud', null=True, editable=False, blank=True)),
                ('answer_date', models.DateTimeField(verbose_name='Fecha de respuesta', null=True, editable=False, blank=True)),
            ],
            options={
                'permissions': [('list_paymentanswer', 'Can list paymentanswer'), ('detail_paymentanswer', 'Can view paymentanswer')],
            },
        ),
        migrations.CreateModel(
            name='PaymentConfirmation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creado')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('ref', models.CharField(max_length=50, verbose_name='Referencia')),
                ('action', models.CharField(max_length=7, verbose_name='Acci\xf3n', choices=[(b'confirm', 'Confirmar'), (b'cancel', 'Cancelar')])),
                ('data', models.TextField(null=True, verbose_name='Dato', blank=True)),
            ],
            options={
                'permissions': [('list_paymentconfirmation', 'Can list paymentconfirmation'), ('detail_paymentconfirmation', 'Can view paymentconfirmation')],
            },
        ),
        migrations.CreateModel(
            name='PaymentRequest',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creado')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('ref', models.CharField(max_length=50, verbose_name='Referencia')),
                ('platform', models.CharField(max_length=20, verbose_name='Plataforma', choices=[(b'sabadell', b'Sabadell')])),
                ('protocol', models.CharField(max_length=10, verbose_name='Protocol', choices=[(b'paypal', 'Paypal'), (b'redsys', 'Redsys'), (b'redsysxml', 'Redsys XML')])),
                ('real', models.BooleanField(default=False, verbose_name='Real')),
                ('error', models.BooleanField(default=False, verbose_name='Error')),
                ('error_txt', models.TextField(null=True, verbose_name='Error del text', blank=True)),
                ('cancelled', models.BooleanField(default=False, verbose_name='Cancelado')),
                ('total', models.FloatField(verbose_name='Total')),
                ('notes', models.CharField(max_length=30, null=True, verbose_name='Notas', blank=True)),
                ('request', models.TextField(null=True, verbose_name='Solicitud', blank=True)),
                ('answer', models.TextField(null=True, verbose_name='Respuesta', blank=True)),
                ('request_date', models.DateTimeField(verbose_name='Fecha de solicitud', null=True, editable=False, blank=True)),
                ('answer_date', models.DateTimeField(verbose_name='Fecha de respuesta', null=True, editable=False, blank=True)),
                ('currency', models.ForeignKey(on_delete=models.CASCADE, related_name='payments', to='codenerix_payments.Currency')),
            ],
            options={
                'permissions': [('list_paymentrequest', 'Can list paymentrequest'), ('detail_paymentrequest', 'Can view paymentrequest')],
            },
        ),
        migrations.AddField(
            model_name='paymentconfirmation',
            name='payment',
            field=models.ForeignKey(on_delete=models.CASCADE, related_name='paymentconfirmations', to='codenerix_payments.PaymentRequest'),
        ),
        migrations.AddField(
            model_name='paymentanswer',
            name='payment',
            field=models.ForeignKey(on_delete=models.CASCADE, related_name='paymentanswers', to='codenerix_payments.PaymentRequest'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0006_auto_20160824_1524'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymentconfirmation',
            name='error',
            field=models.BooleanField(default=False, verbose_name='Error'),
        ),
        migrations.AddField(
            model_name='paymentconfirmation',
            name='error_txt',
            field=models.TextField(null=True, verbose_name='Error Text', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='platform',
            field=models.CharField(max_length=20, verbose_name='Platform', choices=[(b'paypalonline', b'Paypalonline')]),
        ),
    ]
